<p align="center">
Send notification once long running command is finished. Add duration PROMP_FIELD.
</p>

<p align="center">
If you like the idea click ⭐ on the repo and stay tuned.
</p>

## Installation

To install use pip:

``` bash
xpip install xontrib-cmd-done
# or: xpip install -U git+https://github.com/jnoortheen/xontrib-cmd-done
```

## Usage

``` bash
xontrib load cmd_done
```

## Examples

``` bash
$RIGHT_PROMPT = '{long_cmd_duration:⌛{}}{user:{{BOLD_RED}}🤖{}}{hostname:{{BOLD_#FA8072}}🖥{}}'
```

## Credits

This package was created with [xontrib cookiecutter template](https://github.com/jnoortheen/xontrib-cookiecutter).
